package org.xmldb.xupdate.unittests;

/*
 *  The XML:DB Initiative Software License, Version 1.0
 *
 *
 * Copyright (c) 2000-2003 The XML:DB Initiative.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        XML:DB Initiative (http://www.xmldb.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "XML:DB Initiative" must not be used to endorse or
 *    promote products derived from this software without prior written
 *    permission. For written permission, please contact info@xmldb.org.
 *
 * 5. Products derived from this software may not be called "XML:DB",
 *    nor may "XML:DB" appear in their name, without prior written
 *    permission of the XML:DB Initiative.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the XML:DB Initiative. For more information
 * on the XML:DB Initiative, please see <http://www.xmldb.org/>.
 */

import junit.framework.TestCase;
import org.apache.xml.serialize.DOMSerializer;
import org.apache.xml.serialize.OutputFormat;
import org.apache.xml.serialize.XMLSerializer;
import org.apache.xpath.XPathAPI;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.traversal.DocumentTraversal;
import org.w3c.dom.traversal.NodeFilter;
import org.w3c.dom.traversal.NodeIterator;
import org.xmldb.common.xml.queries.XUpdateQuery;
import org.xmldb.xupdate.lexus.XUpdateQueryImpl;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import java.io.StringWriter;

/**
 *
 */
public class LexusTestCase extends TestCase {

  private static Document updates;
  private static DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();

  static final String RESOURCE_LOCATION = "org/xmldb/xupdate/unittests/";
  static final String XPATHQUERYFACTORY = "org.xmldb.common.xml.queries.xalan2.XPathQueryFactoryImpl";

  /**
   *
   */
  public LexusTestCase(String name) {
    super(name);
  }

  public void mainTest(String test) throws Exception {
    if (updates == null) {
      updates = parseInputFile(RESOURCE_LOCATION + "tests.xml");
    }

    Node xupdateQuery = XPathAPI.selectSingleNode(updates, "/tests/test[@name='" + test + "']/xupdate/*", updates);
    String query = serialize((Element) xupdateQuery);

    Document result = getDocument(updates, "/tests/input[@name=/tests/test[@name='" + test + "']/@input]/*");
    XUpdateQuery xupdate = new XUpdateQueryImpl();
    xupdate.setQString(query);
    System.setProperty("org.xmldb.common.xml.queries.XPathQueryFactory", XPATHQUERYFACTORY);
    xupdate.execute(result);

    removeWhiteSpace(result);
    Document expected = getDocument(updates, "/tests/test[@name='" + test + "']/result/*");
    removeWhiteSpace(expected);

//    System.out.println("expected: \n" + serialize((expected)));
//    System.out.println("result: \n" + serialize(result));

    new XhiveNodeMatcher().compareNodes(expected, result, true, true);
  }

  /**
   * Parses input file and generates DOM.
   */
  private Document parseInputFile(String inputFile) throws Exception {
    DocumentBuilder builder = getDocumentBuilder();
    return builder.parse(inputFile);
  }

  private String serialize(Element element) throws Exception {
    StringWriter writer = new StringWriter();
    getSerializer(writer).serialize(element);
    return writer.toString();
  }

  private String serialize(Document document) throws Exception {
    StringWriter writer = new StringWriter();
    getSerializer(writer).serialize(document);
    return writer.toString();
  }

  private DOMSerializer getSerializer(StringWriter writer) throws Exception {
    OutputFormat outputFormat = new OutputFormat("xml", "UTF-8", true);
    XMLSerializer serializer = new XMLSerializer(writer, outputFormat);
    return serializer.asDOMSerializer();
  }

  private DocumentBuilder getDocumentBuilder() throws Exception {
    factory.setNamespaceAware(true);
    DocumentBuilder builder = factory.newDocumentBuilder();
    return builder;
  }

  private Document getDocument(Node contextNode, String query) throws Exception {
    Node result = XPathAPI.selectSingleNode(contextNode, query, contextNode);
    DocumentBuilder builder = getDocumentBuilder();
    Document document = builder.newDocument();
    result = document.importNode(result, true);
    document.appendChild(result);
    return document;
  }

  private void removeWhiteSpace(Node context) {
    DocumentTraversal traversal = context instanceof Document
            ? (DocumentTraversal) context
            : (DocumentTraversal) context.getOwnerDocument();
    NodeIterator nodeIterator = traversal.createNodeIterator(context, NodeFilter.SHOW_TEXT, null, true);
    Node node = nodeIterator.nextNode();
    while (node != null) {
      if (node.getNodeValue().trim().compareTo("") == 0) {
        node.getParentNode().removeChild(node);
      }
      node = nodeIterator.nextNode();
    }
  }
}
